## Benchmarks

In order to run the benchmarks, install the `richbench` package first:

```shell
$ pip install richbench
```

Then you can run the benchmarks with:

```shell
$ richbench benchmarks/
```
